@@ -27,6 +27,7 @@ def parse_args():
     parser.add_argument("--db-file", help="history database file to write to", default="download_history.sqlite")
     parser.add_argument("--threads", type=int, help="number of threads to use (0 = max)", default=0)
     parser.add_argument("--attempts", type=int, help="number of attempts to download each file", default=10)
+    parser.add_argument("--connection-timeout", type=int, help="number of seconds to wait attempting to connect to a URL during the downloading phase", default=15)
     parser.add_argument("--disable-attempt-limit", help="disables the attempt limitation", action="store_true")
     parser.add_argument("--include-id", help="include the ID in the download folder name", action="store_true")
     parser.add_argument("--exclude-videos", help="skip downloading of video files", action="store_true")
@@ -75,6 +76,12 @@ async def download_all(args: argparse.Namespace):
     with open(input_file, "r", encoding="utf8") as f:
         links += await regex_links(f.read())
 
+    links = list(filter(None, links))
+
+    if not links:
+        await log("No links found, check the URL.txt\nIf the link works in your web browser, "
+                  "please open an issue ticket with me.", Fore.RED)
+
     leakednudes_auth = AuthData(args.leakednudes_username, args.leakednudes_password)
     socialmediagirls_auth = AuthData(args.socialmediagirls_username, args.socialmediagirls_password)
     simpcity_auth = AuthData(args.simpcity_username, args.simpcity_password)
@@ -86,8 +93,7 @@ async def download_all(args: argparse.Namespace):
 
     if await content_object.is_empty():
         logging.error('ValueError No links')
-        await log("No links found, check the URL.txt\nIf the link works in your web browser, "
-                  "please open an issue ticket with me.", Fore.RED)
+        await log("No links found duing scraping, check passwords or that the urls are accessible", Fore.RED)
         await log("This program does not currently support password protected albums.", Fore.RED)
         exit(0)
     await clear()
@@ -97,7 +103,7 @@ async def download_all(args: argparse.Namespace):
                                         excludes=excludes, SQL_helper=SQL_helper, client=client)
 
     for downloader in downloaders:
-        await downloader.download_content()
+        await downloader.download_content(conn_timeout=args.connection_timeout)
     logger.debug("Finished")
 
     partial_downloads = [str(f) for f in args.output_folder.rglob("*.part") if f.is_file()]
